@@ -35,7 +35,8 @@ class ConsoleLogger:
             print(f"{cur}\t{self.t}\t{info}\t")
 
     def error(self, info, ts=0):
-        self.log(self.t, info, ts)
+        cur = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time()))
+        print(f"{cur}\t{self.t}\t{info}\t")
 
     def __str__(self):
         return 'ConsoleLogger'
